"""
broadway.config
~~~~~~~~~~~~~~

A schema for the default flask config.

:copyright: (c) 2017 Daniel Knell
:license: MIT, see LICENSE for more details.
"""

import datetime

import flask.helpers

SCHEMA = {
    'DEBUG': {
        'type': bool,
        'default': flask.helpers.get_debug_flag(default=False),
    },
    'TESTING': {
        'type': bool,
        'default': False,
    },
    'PROPAGATE_EXCEPTIONS': {
        'type': bool,
        'default': None,
    },
    'PRESERVE_CONTEXT_ON_EXCEPTION': {
        'type': bool,
        'default': None,
    },
    'SECRET_KEY': {
        'type': str,
    },
    'PERMANENT_SESSION_LIFETIME': {
        'type': int,
        'default': 31 * 24 * 60 * 60,  # 31 days
        'mapper': lambda seconds: datetime.timedelta(seconds=seconds)
    },
    'USE_X_SENDFILE': {
        'type': bool,
        'default': False,
    },
    'LOGGER_NAME': {
        'type': str,
        'default': None,
    },
    'LOGGER_HANDLER_POLICY': {
        'type': str,
        'default': 'always',
    },
    'SERVER_NAME': {
        'type': str,
        'default': None,
    },
    'APPLICATION_ROOT': {
        'type': str,
        'default': None,
    },
    'SESSION_COOKIE_NAME': {
        'type': str,
        'default': 'session',
    },
    'SESSION_COOKIE_DOMAIN': {
        'type': str,
        'default': None,
    },
    'SESSION_COOKIE_PATH': {
        'type': str,
        'default': None,
    },
    'SESSION_COOKIE_HTTPONLY': {
        'type': bool,
        'default': True,
    },
    'SESSION_COOKIE_SECURE': {
        'type': bool,
        'default': False,
    },
    'SESSION_REFRESH_EACH_REQUEST': {
        'type': bool,
        'default': True,
    },
    'MAX_CONTENT_LENGTH': {
        'type': int,
        'default': None,
    },
    'SEND_FILE_MAX_AGE_DEFAULT': {
        'type': int,
        'default': 12 * 24 * 60 * 60,  # 12 days
        'mapper': lambda seconds: datetime.timedelta(seconds=seconds)
    },
    'TRAP_BAD_REQUEST_ERRORS': {
        'type': bool,
        'default': False,
    },
    'TRAP_HTTP_EXCEPTIONS': {
        'type': bool,
        'default': False,
    },
    'EXPLAIN_TEMPLATE_LOADING': {
        'type': bool,
        'default': False,
    },
    'PREFERRED_URL_SCHEME': {
        'type': str,
        'default': 'http',
    },
    'JSON_AS_ASCII': {
        'type': bool,
        'default': True,
    },
    'JSON_SORT_KEYS': {
        'type': bool,
        'default': True,
    },
    'JSONIFY_PRETTYPRINT_REGULAR': {
        'type': bool,
        'default': True,
    },
    'JSONIFY_MIMETYPE': {
        'type': str,
        'default': 'application/json',
    },
    'TEMPLATES_AUTO_RELOAD': {
        'type': bool,
        'default': None,
    },
}
