"""
broadway.whitenoise
~~~~~~~~~~~~~~~~~~~

An extension to serve static content via whitenoise.

:copyright: (c) 2017 Daniel Knell
:license: MIT, see LICENSE for more details.
"""

from __future__ import absolute_import

import whitenoise

SCHEMA = {
    'WHITENOISE_MAX_AGE': {
        'type': int,
        'default': 60
    },
    'WHITENOISE_CHARSET': {
        'type': str,
        'default': 'utf-8'
    },
    'WHITENOISE_ALLOW_ALL_ORIGINS': {
        'type': bool,
        'default': True
    },
}


def register(factory):
    """
    Register the extension with a broadway factory.
    """
    factory.add_config_schema(SCHEMA)


def init_app(application):
    """
    Initialise an application

    Set up whitenoise to handle static files.
    """
    config = {k: v for k, v in application.config.items() if k in SCHEMA}

    kwargs = {'autorefresh': application.debug}

    kwargs.update((k[11:].lower(), v) for k, v in config.items())

    instance = whitenoise.WhiteNoise(application.wsgi_app, **kwargs)

    instance.add_files(application.static_folder, application.static_url_path)

    if not hasattr(application, 'extensions'):
        application.extensions = {}

    application.extensions['whitenoise'] = instance

    application.wsgi_app = instance
